==> bootstrap-2.12.0.tgz: package/src/pages/full-page.js <==
// dependencies
import React from "react";

// components
import Container from "react-bootstrap/Container";
import { Helmet } from "react-helmet";
import Navbar from "react-bootstrap/Navbar";

// LegendaryMediaTV functions
import { title } from "../../functions";

// LegendaryMediaTV components
import FullPage from "../../FullPage";

const FullPagePage = () => {
  return (
    <>
      <Helmet htmlAttributes={{ lang: "en" }}>
        <title>
          {title("LegendaryMediaTV", "Full Page Demo", "Bootstrap Demo")}
        </title>

        <link
          rel="stylesheet"
          href="https://cdn.jsdelivr.net/npm/bootstrap@4.5.3/dist/css/bootstrap.min.css"
          integrity="sha384-TX8t27EcRE3e/ihU7zmQxVncDAy5uIKz4rEkgIXeMed4M0jlfIDPvg6uqKI2xXr2"
          crossorigin="anonymous"
        />
      </Helmet>
      <div className="bg-dark">
        <Container className="bg-light p-0">
          <FullPage>
            <FullPage.Content>
              <Navbar bg="primary" variant="dark">
                <Navbar.Brand>LegendaryMediaTV</Navbar.Brand>
              </Navbar>
              <article className="py-4 px-2">
                <h1>Title or whatever</h1>
                <p>Things, stuff, content!</p>
              </article>
            </FullPage.Content>
            <FullPage.Footer className="bg-secondary py-2 text-center text-white">
              Footer Content
            </FullPage.Footer>
          </FullPage>
        </Container>
      </div>
    </>
  );
};

export default FullPagePage;

==> bootstrap-3.0.1.tgz: package/src/pages/full-page.js <==
// dependencies
import React from "react";

// components
import Container from "react-bootstrap/Container";
import { Helmet } from "react-helmet";
import Navbar from "react-bootstrap/Navbar";

// LegendaryMediaTV functions
import { title } from "../../functions";

// LegendaryMediaTV components
import FullPage from "../../FullPage";

const FullPagePage = () => {
  return (
    <>
      <Helmet htmlAttributes={{ lang: "en" }}>
        <title>
          {title("LegendaryMediaTV", "Full Page Demo", "Bootstrap Demo")}
        </title>

        <link
          rel="stylesheet"
          href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.1/dist/css/bootstrap.min.css"
          integrity="sha384-F3w7mX95PdgyTmZZMECAngseQB83DfGTowi0iMjiWaeVhAn4FJkqJByhZMI3AhiU"
          crossorigin="anonymous"
        />
      </Helmet>

      <div className="bg-dark">
        <Container className="bg-light p-0">
          <FullPage>
            <FullPage.Content>
              <Navbar bg="primary" variant="dark">
                <Navbar.Brand>LegendaryMediaTV</Navbar.Brand>
              </Navbar>

              <article className="py-4 px-2">
                <h1>Title or whatever</h1>
                <p>Things, stuff, content!</p>
              </article>
            </FullPage.Content>

            <FullPage.Footer className="bg-secondary py-2 text-center text-white">
              Footer Content
            </FullPage.Footer>
          </FullPage>
        </Container>
      </div>
    </>
  );
};

export default FullPagePage;
